@@ -1,6 +1,7 @@
 import configparser
 import argparse
 import requests
+import subprocess
 import os
 
 def send(url, content: str) -> None:
@@ -30,11 +31,26 @@ def main():
             config.write(configfile)
     
     parser.add_argument("cmd", help="the task to excecute")
+    parser.add_argument("-m", help="the message to be sent")
 
     args = parser.parse_args()
 
-    os.system(args.cmd)
-    send(url=hook_url, content="cmd complete")
+    cmd = args.cmd.split()
+    if cmd[0] in ["python", "python3"]:
+        cmd.insert(1, "-u")
+    # print(cmd)
+    process = subprocess.Popen(cmd, stdout=subprocess.PIPE)
+
+    while process.stdout.readable():
+        line = process.stdout.readline()
+        if not line:
+            break
+        string = bytes.decode(line.strip())
+
+    if args.m != None:
+        send(url=hook_url, content=args.m)
+    else:
+        send(url=hook_url, content="cmd complete")
 
 
 if __name__ == '__main__':
